@@ -1,16 +1,13 @@
-use 5.006;
-use strict;
-use warnings;
 package Email::Simple;
 
+use 5.00503; # why? -- rjbs, 2007-04-01
+use strict;
 use Carp ();
 
-use Email::Simple::Creator;
 use Email::Simple::Header;
 
-our $VERSION = '2.200_02';
-$VERSION = eval $VERSION;
-our $GROUCHY = 0;
+$Email::Simple::VERSION = '2.001';
+$Email::Simple::GROUCHY = 0;
 
 # We are liberal in what we accept.
 sub __crlf_re { qr/\x0a\x0d|\x0d\x0a|\x0a|\x0d/; }
@@ -21,7 +18,6 @@ Email::Simple - simple parsing of RFC2822 message format and headers
 
 =head1 SYNOPSIS
 
-  use Email::Simple;
   my $email = Email::Simple->new($text);
 
   my $from_header = $email->header("From");
@@ -34,21 +30,6 @@ Email::Simple - simple parsing of RFC2822 message format and headers
 
   print $email->as_string;
 
-...or, to create a message from scratch...
-
-  my $email = Email::Simple->create(
-      header => [
-        From    => 'casey@geeknest.com',
-        To      => 'drain@example.com',
-        Subject => 'Message in a bottle',
-      ],
-      body => '...',
-  );
-  
-  $email->header_set( 'X-Content-Container' => 'bottle/glass' );
-  
-  print $email->as_string;
-
 =head1 DESCRIPTION
 
 C<Email::Simple> is the first deliverable of the "Perl Email Project."  The
@@ -64,12 +45,12 @@ external dependencies, and correct.
   my $email = Email::Simple->new($message, \%arg);
 
 This method parses an email from a scalar containing an RFC2822 formatted
-message and returns an object.  C<$message> may be a reference to a message
+message, and return an object.  C<$message> may be a reference to a message
 string, in which case the string will be altered in place.  This can result in
 significant memory savings.
 
-If you want to create a message from scratch, you should use the C<L</create>>
-method.
+If you want to create a message from scratch, you should use the plugin
+L<Email::Simple::Creator>.
 
 Valid arguments are:
 
@@ -99,14 +80,14 @@ sub new {
     $text_ref = \'';
   }
 
-  my $header_class = $arg->{header_class} || $self->default_header_class;
+  $self->body_set($text_ref);
+
+  my $header_class = $arg->{header_class} || $self->_default_header_class;
 
   $self->header_obj_set(
     $header_class->new(\$head, { crlf => $self->crlf })
   );
 
-  $self->body_set($text_ref);
-
   return $self;
 }
 
@@ -124,63 +105,10 @@ sub _split_head_from_body {
   } else {
 
     # The body is, of course, optional.
-    $$text_ref =~ /($crlf)/gsm;
-    return (undef, ($1 || "\n"));
+    return (undef, "\n");
   }
 }
 
-=head2 create
-
-  my $email = Email::Simple->create(header => [ @headers ], body => '...');
-
-This method is a constructor that creates an Email::Simple object
-from a set of named parameters. The C<header> parameter's value is a
-list reference containing a set of headers to be created. The C<body>
-parameter's value is a scalar value holding the contents of the message
-body.  Line endings in the body will normalized to CRLF.
-
-If no C<Date> header is specified, one will be provided for you based on the
-C<gmtime> of the local machine. This is because the C<Date> field is a required
-header and is a pain in the neck to create manually for every message. The
-C<From> field is also a required header, but it is I<not> provided for you.
-
-=cut
-
-our $CREATOR = 'Email::Simple::Creator';
-
-sub create {
-  my ($class, %args) = @_;
-
-  # We default it in here as well as below because by having it here, then we
-  # know that if there are no other headers, we'll get the proper CRLF.
-  # Otherwise, we get a message with incorrect CRLF. -- rjbs, 2007-07-13
-  my $headers = $args{header} || [ Date => $CREATOR->_date_header ];
-  my $body    = $args{body} || '';
-
-  my $empty   = q{};
-  my $header  = \$empty;
-
-  for my $idx (map { $_ * 2 } 0 .. @$headers / 2 - 1) {
-    my ($key, $value) = @$headers[ $idx, $idx + 1 ];
-    $CREATOR->_add_to_header($header, $key, $value);
-  }
-
-  $CREATOR->_finalize_header($header);
-
-  my $email = $class->new($header);
-
-  $email->header_set(Date => $CREATOR->_date_header)
-    unless defined $email->header('Date');
-
-  $body = (join $CREATOR->_crlf, split /\x0d\x0a|\x0a\x0d|\x0a|\x0d/, $body)
-        . $CREATOR->_crlf;
-
-  $email->body_set($body);
-
-  return $email;
-}
-
-
 =head2 header_obj
 
   my $header = $email->header_obj;
@@ -227,8 +155,7 @@ context, it returns the I<first> value for the named header.
     $email->header_set($field, $line1, $line2, ...);
 
 Sets the header to contain the given data. If you pass multiple lines
-in, you get multiple headers, and order is retained.  If no values are given to
-set, the header will be removed from to the message entirely.
+in, you get multiple headers, and order is retained.
 
 =head2 header_names
 
@@ -280,7 +207,7 @@ sub body_set {
   my ($self, $text) = @_;
   my $text_ref = ref $text ? $text : \$text;
   $self->{body} = $text_ref;
-  return;
+  $self->body;
 }
 
 =head2 as_string
@@ -303,14 +230,14 @@ only.
 
 sub crlf { $_[0]->{mycrlf} }
 
-=head2 default_header_class
+#=head2 default_header_class
+#
+#This returns the class used, by default, for header objects, and is provided
+#for subclassing.  The default default is Email::Simple::Header.
+#
+#=cut
 
-This returns the class used, by default, for header objects, and is provided
-for subclassing.  The default default is Email::Simple::Header.
-
-=cut
-
-sub default_header_class { 'Email::Simple::Header' }
+sub _default_header_class { 'Email::Simple::Header' }
 
 1;
 
@@ -329,7 +256,7 @@ L<http://rt.cpan.org/NoAuth/Bug.html?id=2478>.
 
 This module is maintained by the Perl Email Project
 
-L<http://emailproject.perl.org/>
+L<http://emailproject.perl.org/wiki/Email::Simple>
 
 =head1 AUTHORS
 
